# -*- coding: utf-8 -*-
"""
@File    : convert_util.py
@Date    : 2024-04-03
"""


def convert_key(convert_key_map, convert_data):
    """
    中文键和英文键转换
    :param convert_key_map: dict
    :param convert_data: dict
    :return: dict
    """
    def convert(key_map, data):
        if not data:
            return data

        item = {}

        for k, v in key_map.items():

            # 更丰富的配置
            if isinstance(v, dict):
                item_key = v['value']
                children = v.get('children')
                child = v.get('child')

                if child:
                    # dict
                    item_value = convert(child, data.get(k))

                elif children:
                    # list
                    lst = []
                    for child_d in data.get(k):
                        lst.append(convert(children, child_d))

                    item_value = lst
                else:
                    # string
                    item_value = data.get(k, '')
            else:
                item_key = v
                item_value = data.get(k, '')

            item[item_key] = item_value

        return item

    return convert(convert_key_map, convert_data)



# -*- coding: utf-8 -*-
"""
@File    : kcb_stock.py
@Date    : 2023-07-17
科创板相关接口
"""

from stock_open_api.api.eastmoney import kcb_stock_config, sh_stock
from stock_open_api.items.list_item import ListItem
from stock_open_api.utils import time_util, request_util, json_util


def get_list(page=1, size=20):
    """
    科创板列表
    东方财富网 > 行情中心 > 沪深京个股 > 科创板
    http://quote.eastmoney.com/center/gridlist.html#kcb_board

    :param page: int
    :param size: int

    :return: ListItem

    >>> get_list()
    {
      "total": 553
      "items": [
        {
          "代码": "688627",
          "名称": "N精智达",
          "最新价": 76.6,
          "涨跌幅": 63.78,
          "涨跌额": 29.83,
          "成交量(手)": 164038,
          "成交额": 1225759938.0,
          "振幅": 42.61,
          "最高": 85.93,
          "最低": 66.0,
          "今开": 66.1,
          "昨收": 46.77,
          "量比": "-",
          "换手率": 82.17,
          "市盈率(动态)": -526.17,
          "市净率": 4.54,
          "总市值": 7201300356,
          "流通市值": 1529094485,
          "60日涨跌幅": 63.78,
          "年初至今涨跌幅": 63.78,
          "涨速": 0.13,
          "5分钟涨跌": -0.8
        }
      ]
    }
    """
    url = 'http://99.push2.eastmoney.com/api/qt/clist/get'

    params = {
        # "cb": "jQuery112404122955256524934_1689658637418",
        'pn': page,
        'pz': size,
        "po": "1",
        "np": "1",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f3",
        "fs": "m:1 t:23",
        "fields": "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f20,f21,f23,f24,f25,f22,f11,f62,f128,f136,f115,f152",
        '_': time_util.get_timespan_13()

    }

    res = request_util.get(url, params)

    data = res.json()

    list_item = ListItem()
    if data['data'] is None:
        return list_item

    list_item.total = data['data']['total']

    items = []
    for row in data['data']['diff']:
        item = {}

        for map_item in kcb_stock_config.list_key_map:
            item[map_item['title']] = row.get(map_item['key'])

        items.append(item)

    list_item.items = items
    return list_item


def get_company_info(code):
    """
    科创板 公司 基本资料 | 发行相关
    https://emweb.securities.eastmoney.com/PC_HSF10/CompanySurvey/Index?type=web&code=sh688092

    :param code: str eg: 688092

    :return:

    >>> get_company_info('688627')
    {
      "公司名称": "志邦家居股份有限公司",
      "英文名称": "Zbom Home Collection Co.,Ltd",
      "A股代码": "603801",
      "A股简称": "志邦家居",
      "A股扩位简称": null,
      "曾用名": "志邦股份",
      "B股代码": null,
      "B股简称": null,
      "H股代码": null,
      "H股简称": null,
      "证券类别": "上交所主板A股",
      "上市交易所": "上海证券交易所",
      "所属东财行业": "轻工制造-家具-家具制造",
      "所属证监会行业": "制造业-家具制造业",
      "总经理": "许帮顺",
      "法人代表": "孙志勇",
      "董秘": "孙娟",
      "董事长": "孙志勇",
      "证券事务代表": "臧晶晶",
      "独立董事": "鲁昌华,张京跃,王文兵",
      "联系电话": "0551-67186564",
      "电子信箱": "zbom@zbom.com",
      "传真": "0551-65203999",
      "公司网址": "www.zbom.com",
      "办公地址": "安徽省合肥市庐阳工业区连水路19号",
      "注册地址": "安徽省合肥市庐阳工业区连水路19号",
      "区域": "安徽",
      "邮政编码": "230061",
      "注册资本(元)": 43654.7813,
      "工商登记": "91340100772816763N",
      "雇员人数": 5151,
      "管理人员人数": 16,
      "律师事务所": "安徽天禾律师事务所",
      "会计师事务所": "大华会计师事务所(特殊普通合伙)",
      "公司介绍": "志邦家居股份有限公司创立于1998年,是中国厨柜行业的先行者。现在,志邦专注于整家定制家居的研发、设计、生产与销售。从“更懂生活”的品牌理念出发,以整家生活的定制设计和服务为优势,为亿万家庭提供从厨房到全屋的整家解决方案。作为整家定制领域的专业家居品牌,志邦家居为人们提供整体厨房、全屋定制、木门墙板、成品家配为核心的整家一体化设计、制造、交付业务,在全国拥有六大生产基地,引进国外智能化制造设备,整合优质供应链,确保产品从设计、生产、安装到服务的每一个环节都以人为尺度、以生活为核心,为全球家庭创造理想的家居良品。凭借卓越的品质和口碑,志邦家居获得“中国环境标志认证”“FSC国际森林认证”等60余项国内外权威认证,同时成为国内诸多知名地产商的重要战略合作伙伴;志邦家居的产品远销海外,出口至澳洲、北美、东南亚、中东等国家和地区,是丽思卡尔顿、瑰丽酒店等国际五星级酒店优质供应商,在东南亚开设多家品牌专营店,品牌享誉全球。自2009年起,志邦家居与央视等主流媒体达成战略合作,并于2016年强势进驻纽约时代广场。同年签约前世界跳水冠军郭晶晶女士为品牌形象代言人,并先后联手郎平、杜丽等世界冠军和蔡康永、陈小春、罗嘉良、许茹芸、杨烁、孙杨、吴莫愁、王耀庆、钟汉良、张智霖、李晨等众多明星共同为美好生活赋义。2017年6月30日,志邦家居在上交所A股上市,2019年1月,正式签约世界著名音乐人周杰伦先生为品牌全新形象代言人。未来,我们将以专业的整家定制服务,发现和满足人们对生活空间的需求;以前沿的产品设计,引领和启发人们对生活品质的向往;以稳健的成长,为社会的良性发展创造更多真实的价值。志邦家居致力成为中国家居行业的一流企业、全球家居行业的领先企业,为现实现人们对家的美好想象奋力前行。",
      "经营范围": "家具制造;家具零配件生产;家具零配件销售;家具销售;家具安装和维修服务;地板制造;地板销售;门窗制造加工;门窗销售;金属门窗工程施工;楼梯制造;楼梯销售;家居用品制造;家居用品销售;建筑装饰材料销售;木材加工;家用电器研发;家用电器制造;家用电器销售;家用电器零配件销售;家用电器安装服务;家用纺织制成品制造;非电力家用器具制造;非电力家用器具销售;卫生洁具研发;卫生洁具制造;卫生洁具销售;厨具卫具及日用杂品研发;厨具卫具及日用杂品批发;厨具卫具及日用杂品零售;日用品销售;灯具销售;互联网销售(除销售需要许可的商品);五金产品批发;五金产品零售;燃气器具生产;电子产品销售;第一类医疗器械销售;第二类医疗器械销售;普通货物仓储服务(不含危险化学品等需许可审批的项目);装卸搬运;会议及展览服务;供应链管理服务;专业设计服务;工业设计服务;咨询策划服务;住房租赁;非居住房地产租赁;货物进出口。",
      "成立日期": "2005-04-04",
      "上市日期": "2017-06-30",
      "发行市盈率(倍)": 22.92,
      "网上发行日期": "2017-06-20",
      "发行方式": "网上定价发行,网下询价配售,市值申购",
      "每股面值(元)": 1,
      "发行量(股)": 40000000,
      "每股发行价(元)": 23.47,
      "发行费用(元)": 89434000,
      "发行总市值(元)": 938800000,
      "募集资金净额(元)": 849366000,
      "首日开盘价(元)": 33.8,
      "首日收盘价(元)": 33.8,
      "首日换手率": 0.0914,
      "首日最高价(元)": 33.8,
      "网下配售中签率": 0.02743221,
      "定价中签率": 0.03205759
    }

    """
    return sh_stock.get_company_info(code)


if __name__ == '__main__':
    # print(json_util.format_json(get_list().to_dict()))
    print(json_util.format_json(get_company_info('688092')))



# -*- coding: utf-8 -*-
"""
@File    : json_util.py
@Date    : 2023-07-18
"""
import json


def format_json(data):
    return json.dumps(data, indent=2, ensure_ascii=False)


def dump_json(data):
    print(json.dumps(data, indent=2, ensure_ascii=False))



# -*- coding: utf-8 -*-
"""
@File    : neeq_stock.py
@Date    : 2024-04-02
"""
import re

from parsel import Selector

from stock_open_api.api.ipo3 import config
from stock_open_api.utils import request_util, table_util, convert_util
from stock_open_api.log import logger


def get_company_info(stock_code, english_key=False):
    """
    获取股票详情信息

    页面地址：https://www.ipo3.com/company-show/stock_code-430510.html

    :param stock_code: 股票代码
    :return:

    eg:
    {
      "股票名称": "丰光精密",
      "股票代码": "430510",
      "最新价": "17.32",
      "涨跌额": "-1.18",
      "涨跌幅": "-6.38%",
      "所属行业": "机械基础件",
      "今开": "19.89",
      "最高": "19.92",
      "平均价": "18.96",
      "市盈率": "33.26",
      "成交量": "2.76万",
      "总市值": "24.34亿",
      "昨收": "19.79",
      "最低": "18.47",
      "换手率": "4.38%",
      "市净率": "6.19%",
      "成交额": "5225.06万",
      "流通市值": "11.64亿",
      "公司名称": "青岛丰光精密机械股份有限公司",
      "公司网址": "http://www.qdfg.cn",
      "公司电话": "0532-87273590",
      "董秘": "吕冬梅",
      "董秘Email": "fgzq@fengguang.net.cn",
      "董秘电话": "0532-87273528",
      "法人": "李军",
      "主办券商": "中信证券",
      "交易方式": "集合竞价",
      "挂牌日期": "1970-01-01",
      "成立日期": "2001-07-19",
      "做市日期": "2015-07-28",
      "注册资本": "13158.1378 万元",
      "所属地区": "山东省-青岛市",
      "办公地址": "山东省青岛市胶州市胶州湾工业园太湖路2号",
      "公司简介": "青岛丰光精密机械股份有限公司是一家以高精密部品的加工和组装,以及铝制品铸造为核心技术和核心产品的国家级高新技术企业,先后通过了国际质量管理体系ISO9001认证和汽车行业生产件与相关服务件质量管理体系IATF16949认证等管理体系。2021年11月15日成为北交所首批上市企业。公司现有三个生产工厂,并在美国设立全资子公司,拥有数百台国外进口品牌数控加工中心、数控车床、高精度磨床、压铸机等加工、压铸及检测设备,拥有恒温恒湿的欧标标准化生产车间。随着业务的不断扩大及企业的高速发展,公司在中国——上海合作组织地方经贸合作示范区,正在建设中的上合工厂,占地10万平方米。公司产品覆盖半导体、工业自动化、汽车、轨道交通等众多领域。以高精密、高品质、高稳定性的产品赢得了众多国际各行业顶尖制造商的认可,并成为长期战略合作伙伴,如THK集团、安川电机、埃地沃兹、费斯托、山洋电机、盖茨集团、中国中车、阿尔斯通、均胜、日本电产岱高公司以及阿特拉斯等。公司在经营管理过程中,注重技术研发能力的提升,公司先后被评为国家级高新技术企业、青岛市企业技术中心、山东省企业技术中心、青岛市“专精特新”示范企业等。公司通过不断的学习和创新,有较高的自主开发技能,如四轴机器人、六轴机器人,并成功研制开发了多款适合不同行业要求的系列产品等。公司坚持“客户导向”的理念,在精密机械加工件和压铸件方面,根据下游不同行业客户的要求研发、设计产品,并实施最优的生产工序、加工方法及每道工序的加工标准,并进行精细化管理生产,且在工艺技术、生产设备技术先进程度和操控经验等方面处于国内领先水平。公司自成立以来一直秉承取之社会,回报于社会的企业文化理念,除了立足生产、发展企业外,一直积极参与各类社会公益活动,如抗震救灾捐助、小草基金公益捐助、孤寡老人救助、为伤残人士提供就业岗位、帮扶困难员工家庭等行动,希望通过丰光人的点滴行动,传递爱心,帮助更多需要帮助的人。",
      "主营业务": "半导体领域、工业自动化领域、汽车领域、轨道交通领域精密零部件的研发、生产与销售。",
      "经营范围": "精密轴承及各种电机轴的制造，各种精密机械零部件的加工、组装；铝合金部件及锌合金部件压铸成型及加工，金属制品模具设计、制造。（依法须经批准的项目，经相关部门批准后方可开展经营活动）。",
      "融资状态": "定增中",
      "实际募资净额": "4,966.95万",
      "融资成功率": "100.00%",
      "融资排名": "1/14",
      "股本": [
        {
          "总股本": "1.32亿 股",
          "流通股本": "6,292.64万 股",
          "统计日期": "2023-09-30",
          "股东户数": "4,022 户"
        }
      ],
      "股东结构": [
        {
          "股东名称": "青岛丰光投资管理有限公司",
          "持股数": "7,329.50万 股",
          "持股比例": "55.70%"
        }
      ],
      "高管介绍": [
        {
          "姓名": "李军",
          "职位": "董事长",
          "最高学历": "本科",
          "任期开始日期": "2019-09",
          "简介": "李军先生:1970年出生,民建会员,中国国籍,无境外居留权,本科学历。2001年10月至2013年9月,先后担任有限公司副董事长兼总经理董事长兼总经理。2013年9月至2016年3月,担任股份公司董事长兼总经理。2016年4月至今担任股份公司董事长。"
        }
      ],
      "新闻资讯": [
        {
          "标题": "【北交所收评】盘面震荡冲高，北证50大涨近2%，电力、锂电池板块涨幅居前，亿能电力封涨停",
          "摘要": "犀牛之星3月11日讯，今日北交所整体呈现低开高走趋势，午后盘面放量冲高，北证50大涨近2%；受AI算力高耗电量推动，电力板块集体高涨，其中亿能电力（837046）封涨停、灿能电力（870299）涨逾13%；受摩根士丹利上调宁德时代股价提振，午后锂电池概念股震荡走强，天宏锂电（873152）涨逾22%、力王股份（831627）涨逾15%、长虹能源（836239）涨逾13%；次新股铁拓机械（873706）跌逾12%。",
          "地址": "https://www.ipo3.com/company-news/id-1428579.html",
          "来源": "犀牛之星",
          "时间": "2024-03-11 15:24:28"
        }
      ]
    }

    """
    url = "https://www.ipo3.com/company-show/stock_code-{stock_code}.html".format(stock_code=stock_code)

    logger.info("url: %s", url)

    res = request_util.get(url)

    sel = Selector(text=res.text)
    stock_name = sel.css('#stockName::text').extract_first('').strip()
    cur_price = sel.css('.company-detail .cur-price span::text').extract_first('').strip()
    range_num = sel.css('.company-detail .range-num::text').extract_first('').strip()
    range_percent = sel.css('.company-detail .range-percent::text').extract_first('').strip()

    data = {
        '股票名称': stock_name,
        '股票代码': stock_code,
        '最新价': cur_price,
        '涨跌额': range_num,
        '涨跌幅': range_percent,
    }

    # 所属行业
    key, value = sel.css('.industry').xpath('string(.)').extract_first('').split('：')
    data[key.strip()] = value.strip()

    # 市值
    for item in sel.css('.exponent .item'):
        key = item.css('span::text').extract_first('')
        value = item.css('strong::text').extract_first('')
        data[key.strip(':').strip().replace(' ', '')] = value.strip()

    # 基本信息
    for item in sel.css('.company-sheet .sheet-item'):
        key = item.css('span::text').extract_first('').strip('：').strip()
        value = item.css('strong::attr(title)').extract_first('').strip()
        if key == '所属地区':
            value = value.replace(' ', '')

        data[key] = value

    # 定增融资
    for row in sel.css('.strategy-info .strategy-item'):
        key = row.css('.strategy-tit::text').extract_first('').strip()
        value = row.css('.strategy-status::text,span::text').extract_first('').strip()
        if key == '融资排名':
            value = value.replace(' ', '')

        data[key] = value

    #
    for key, value in zip(sel.css('.company-total .lc-title span::text').extract(), sel.css('.company-total .lc-main')):
        key = key.strip()

        if key in ['公司简介', '主营业务', '经营范围']:
            data[key] = value.css('::text').extract_first('').strip()
        elif key in ['股本', '股东结构']:
            items = table_util.parse_table(value)

            if key == '股本':
                lst = []
                for x in items:
                    r = {}
                    for k, v in x.items():
                        # 股东户数 (2022-06-30)
                        ret = re.search('\d{4}-\d{2}-\d{2}', k)
                        if ret:
                            date = ret.group(0)
                            r['统计日期'] = date
                            r['股东户数'] = v
                        else:
                            r[k] = v
                    lst.append(r)
                data[key] = lst
            else:
                data[key] = items
        elif key == '高管介绍':
            items = parse_introduce_table(value)
            for item in items:
                # eg: 2013-09 => 2013-09-01
                if item['任期开始日期'] and len(item['任期开始日期']) == 7:
                    item['任期开始日期'] = item['任期开始日期'] + '-01'

            data[key] = items

        elif key == '新闻资讯':
            data[key] = parse_news_list(value)

    if english_key:
        return convert_util.convert_key(config.COMPANY_INFO_KEY_MAP, data)
    else:
        return data


def parse_introduce_table(sel: Selector):
    """
    解析高管介绍
    :param sel:
    :return:
    """
    lst = []

    # 解析表头
    headers = [x.xpath('string(.)').extract_first('').strip() for x in sel.css('thead th')]

    # 解析内容
    for row, info in zip(sel.css('tbody tr.J_click'), sel.css('tbody tr.info-detail')):
        item = {}

        for key, value in zip(headers, row.css("td")):
            if key == '简介':
                item[key] = info.xpath('string(.)').extract_first('').strip()
            else:
                item[key] = value.xpath('string(.)').extract_first('').strip()

        lst.append(item)

    return lst


def parse_news_list(value: Selector):
    """
    解析文章列表
    :param value:
    :return:
    """
    lst = []
    for row in value.css('.news-item'):
        title = row.css('h3 a::text').extract_first('').strip()
        href = row.css('h3 a::attr(href)').extract_first('').strip()
        summary = row.css('p ::text').extract_first('').strip()

        item = {
            '标题': title,
            '摘要': summary,
            '地址': "https://www.ipo3.com" + href
        }

        for x in row.css('.about span::text').extract():
            key, value = x.split('：')
            item[key.strip()] = value.strip()

        lst.append(item)

    return lst




# -*- coding: utf-8 -*-
"""
table_util.py
"""
from parsel import Selector


def parse_table(sel: Selector):
    """
    标准表格解析工具
    :param sel:
    :return:
    """
    lst = []

    # 解析表头
    headers = [x.xpath('string(.)').extract_first('') for x in sel.css('thead th')]

    # 解析内容
    for row in sel.css('tbody tr'):
        item = {}

        for key, value in zip(headers, row.css("td")):
            item[key] = value.xpath('string(.)').extract_first('').strip()

        lst.append(item)

    return lst



# -*- coding: utf-8 -*-
"""
@File    : stock.py
@Date    : 2023-07-25
"""
import warnings

import six

from stock_open_api.items.list_item import ListItem
from stock_open_api.utils import request_util, excel_util, json_util


class StockType(object):
    Stock_A = 'A股列表'
    Stock_B = 'B股列表'
    Stock_CDR = 'CDR列表'
    Stock_AB = 'A＋B股列表'


INDICATOR_MAP = {
    StockType.Stock_A: "tab1",
    StockType.Stock_B: "tab2",
    StockType.Stock_CDR: "tab3",
    StockType.Stock_AB: "tab4",
}


def get_stock_list(stock_type=StockType.Stock_A):
    """
    深圳证券交易所-股票列表
    http://www.szse.cn/market/product/stock/list/index.html

    代码参考：https://github.com/akfamily/akshare/blob/main/akshare/stock/stock_info.py

    :param stock_type: choice of {"A股列表", "B股列表", "CDR列表", "A+B股列表"}
    :type stock_type: str

    :return: 指定 indicator 的数据
    :rtype: ListItem

    >>> get_stock_list
    {
        "total": 2804,
        "list": [
            {
              "板块": "主板",
              "公司全称": "平安银行股份有限公司",
              "英文名称": "Ping An Bank Co., Ltd.",
              "注册地址": "广东省深圳市罗湖区深南东路5047号",
              "A股代码": "000001",
              "A股简称": "平安银行",
              "A股上市日期": "1991-04-03",
              "A股总股本": "19,405,918,198",
              "A股流通股本": "19,405,546,950",
              "B股代码": "",
              "B股简称": "",
              "B股上市日期": "",
              "B股总股本": "0",
              "B股流通股本": "0",
              "地区": "华南",
              "省份": "广东",
              "城市": "深圳市",
              "所属行业": "J 金融业",
              "公司网址": "bank.pingan.com",
              "未盈利": "-",
              "具有表决权差异安排": "-",
              "具有协议控制架构": "-"
            }
        ]
    }
    """
    url = "http://www.szse.cn/api/report/ShowReport"

    params = {
        "SHOWTYPE": "xlsx",
        "CATALOGID": "1110",
        "TABKEY": INDICATOR_MAP[stock_type],
        "random": "0.6935816432433362",
    }

    r = request_util.get(url, params=params)

    with warnings.catch_warnings(record=True):
        warnings.simplefilter("always")
        lst = excel_util.read_excel(six.BytesIO(r.content))

    list_item = ListItem()
    list_item.items = lst
    list_item.total = len(lst)

    return list_item


if __name__ == '__main__':
    json_util.dump_json(get_stock_list().to_dict())



# -*- coding: utf-8 -*-
"""
@File    : config.py
@Date    : 2024-04-03
"""

COMPANY_INFO_KEY_MAP = {
    "股票名称": "stock_name",
    "股票代码": "stock_code",
    "所属行业": "industry",
    "今开": "open_price",
    "最高": "high_price",
    "平均价": "average_price",
    "市盈率": "pe_ratio",
    "成交量": "volume",
    "总市值": "total_market_value",
    "昨收": "prev_close_price",
    "最低": "low_price",
    "换手率": "turnover_rate",
    "市净率": "pb_ratio",
    "成交额": "turnover",
    "流通市值": "circular_market_value",
    "公司名称": "company_name",
    "公司网址": "company_website",
    "公司电话": "company_phone",
    "董秘": "company_secretary",
    "董秘Email": "company_secretary_email",
    "董秘电话": "company_secretary_phone",
    "法人": "legal_representative",
    "主办券商": "broker",
    "交易方式": "transaction_method",
    "挂牌日期": "listing_date",
    "成立日期": "establish_date",
    "做市日期": "making_date",
    "注册资本": "registered_capital",
    "所属地区": "area",
    "办公地址": "company_address",
    "公司简介": "company_introduction",
    "主营业务": "main_business",
    "经营范围": "business_scope",
    "融资状态": "financing_status",
    "实际募资净额": "financing_actual_net_amount",
    "融资成功率": "financing_success_rate",
    "融资排名": "financing_ranking",
    "股本": {
        'value': "equity",
        'children': {
            "总股本": "total_equity",
            "流通股本": "flow_equity",
            "股东户数": "shareholders_number",
            "统计日期": "date"
        }
    },
    "股东结构": {
        'value': "shareholder_list",
        'children': {
            "股东名称": "shareholder_name",
            "持股数": "shares_number",
            "持股比例": "shareholding_ratio"
        }
    },
    "高管介绍": {
        'value': "manager_list",
        'children': {
            "姓名": "name",
            "职位": "position",
            "最高学历": "highest_education",
            "任期开始日期": "term_start_date",
            "简介": "introduction"
        }
    },
    "新闻资讯": {
        'value': "news_list",
        'children': {
            "标题": "title",
            "摘要": "summary",
            "地址": "url",
            "来源": "source",
            "时间": "publish_time"
        }
    }
}



# -*- coding: utf-8 -*-
"""
@File    : company.py
@Date    : 2023-07-25

同花顺 数据接口
"""
from parsel import Selector

from stock_open_api.utils import request_util, json_util


def get_company_info(code):
    """
    同花顺 股票 详细情况 和 发行相关

    eg:

    查看页面：

    - 个股 http://stockpage.10jqka.com.cn/300763/company
    - 港股 http://stockpage.10jqka.com.cn/HK0700/company/
    - 美股 http://stockpage.10jqka.com.cn/TME/company/

    实际数据页面：http://basic.10jqka.com.cn/300763/company.html

    :param code: 股票代码 eg: 300763
    :type code: str

    :return:
    :rtype: dict

    >>> get_company_info('300763')

    {
      "股票名称": "锦浪科技",
      "股票代码": "300763",
      "详细链接": "http://basic.10jqka.com.cn/300763/company.html",
      "公司名称": "锦浪科技股份有限公司",
      "所属地域": "浙江省",
      "英文名称": "Ginlong Technologies Co.,Ltd.",
      "所属申万行业": "电力设备 — 光伏设备",
      "曾用名": "-",
      "公司网址": "www.ginlong.com",
      "主营业务": "组串式逆变器研发、生产、销售和服务。",
      "产品名称": "",
      "控股股东": "王一鸣",
      "实际控制人": "王一鸣、王峻适、林伊蓓",
      "最终控制人": "王一鸣、王峻适、林伊蓓",
      "董事长": "王一鸣",
      "董秘": "张婵",
      "法人代表": "王一鸣",
      "总经理": "王一鸣",
      "注册资金": "3.97亿元",
      "员工人数": "3994",
      "电话": "86-0574-65802608",
      "传真": "86-0574-65781606",
      "邮编": "315712",
      "办公地址": "浙江省宁波市象山县经济开发区滨海工业园金开路188号",
      "公司简介": "锦浪科技股份有限公司主要从事组串式逆变器研发、生产、销售和服务。公司的主要产品为组串式逆变器,是太阳能光伏发电系统不可缺少的核心设备。公司自2011年起被持续认定为国家高新技术企业。公司是国内较早同时通过欧盟CE认证、澳大利亚SAA认证、美国ETL认证等主流市场认证的组串式并网逆变器生产企业。",
      "成立日期": "2005-09-09",
      "发行数量": "2000.00万股",
      "发行价格": "26.64元",
      "上市日期": "2019-03-19",
      "发行市盈率": "19.6800倍",
      "预计募资": "4.73亿元",
      "首日开盘价": "31.97元",
      "发行": "中签率",
      "实际募资": "5.33亿元",
      "主承销商": "海通证券股份有限公司",
      "历史沿革": "查看全部▼"
    }
    """

    base_url = "http://basic.10jqka.com.cn/{code}/company.html"
    url = base_url.format(code=code)

    res = request_util.get(url)
    res.encoding = res.apparent_encoding

    sel = Selector(text=res.text)
    detail_tds = sel.css("#detail table td")
    publish_tds = sel.css("#publish table td")

    stock_name = sel.css("#stockName::attr(value)").extract_first("")
    stock_code = sel.css("#stockCode::attr(value)").extract_first("")

    item = {
        "股票名称": stock_name,
        "股票代码": stock_code,
        "详细链接": url
    }

    for td in detail_tds + publish_tds:
        key = td.css("strong::text").extract_first("").strip()
        value = td.css("span::text").extract_first("").strip()

        if not value:
            value = td.css("a::text").extract_first("").strip()
        if not value:
            value = td.css("p::text").extract_first("").strip()

        key = key.replace("：", "")
        key = key.replace(" ", "")  # 半角空格(英文符号)\u0020
        key = key.replace("　", "")  # 全角空格(中文符号)\u3000

        if key:
            item[key] = value

    return item


if __name__ == '__main__':
    json_util.dump_json(get_company_info('300763'))



# -*- coding: utf-8 -*-
"""
@File    : sh_stock.py
@Date    : 2023-07-18
上海证券交易所
"""

from stock_open_api.api.eastmoney import company
from stock_open_api.utils import json_util


def get_company_info(code):
    """
    上海证券交易所 公司 基本资料 | 发行相关
    https://emweb.securities.eastmoney.com/PC_HSF10/CompanySurvey/Index?type=web&code=sh688092

    :param code: str eg: 688092

    :return:
    :rtype: dict

    >>> get_company_info('688627')
        {
          "公司名称": "杭州爱科科技股份有限公司",
          "英文名称": "Hangzhou IECHO Science & Technology Co., Ltd.",
          "A股代码": "688092",
          "A股简称": "爱科科技",
          "A股扩位简称": "爱科科技股份",
          "曾用名": null,
          "B股代码": null,
          "B股简称": null,
          "H股代码": null,
          "H股简称": null,
          "证券类别": "上交所科创板A股",
          "上市交易所": "上海证券交易所",
          "所属东财行业": "机械设备-专用设备-其他专用机械",
          "所属证监会行业": "制造业-专用设备制造业",
          "总经理": "方云科",
          "法人代表": "方云科",
          "董秘": "王鹏",
          "董事长": "方小卫",
          "证券事务代表": "戴凌胜,石鑫",
          "独立董事": "顾新建,徐赤,贾勇",
          "联系电话": "0571-86696861,0571-86609578",
          "电子信箱": "office@iechosoft.com",
          "传真": "0571-86698923",
          "公司网址": "www.iechosoft.com",
          "办公地址": "杭州市滨江区伟业路1号1幢",
          "注册地址": "杭州市滨江区伟业路1号1幢",
          "区域": "浙江",
          "邮政编码": "310000",
          "注册资本(元)": 5929.8731,
          "工商登记": "91330108770830908J",
          "雇员人数": 375,
          "管理人员人数": 12,
          "律师事务所": "北京中伦文德(杭州)律师事务所",
          "会计师事务所": "立信会计师事务所(特殊普通合伙)",
          "公司介绍": "杭州爱科科技股份有限公司(公司简称:爱科科技,股票代码:688092)是全球非金属行业智能切割一体化解决方案提供商,以科技创新为基础,面向全球提供智能切割解决方案、系统及服务。生产制造基地建筑面积逾60000平方米,拥有国内先进的设备生产线。公司致力于以高端智能装备核心技术推动我国工业转型升级,能够助力广告文印、汽车内饰、家居家纺、复合材料、纺织服装、办公自动化、鞋业、箱包等多种行业客户实现自动化、智能化、工业化生产。赋能企业转型升级,助力用户降本增效、节能降耗、产品创新,促进用户创造卓越价值。爱科秉承着“客户至上、以人为本”的核心价值观真诚服务每一位用户,公司在杭州建立总部,拥有丰云信息、爱科自动化、爱科机器人等3家子公司,并设立广州和郑州2家分公司及北京、上海、沈阳、长沙、成都等20+办事处,构建了完善的服务机制及网络。公司配备了强大的运维服务团队,7*24小时免费客服热线,为客户提供技术咨询、操作指导及售后服务“全生命周期”的全方位优质服务。目前爱科产品已覆盖亚洲、欧洲、非洲、北美洲、南美洲、大洋洲等100+国家和地区,助力各行业用户开创智能切割新篇章。爱科科技将坚持“以优质服务为宗旨、以客户需求为向导”的经营理念,以创新对话未来,重新定义智能切割新技术,让全球行业用户都能享受到来自爱科科技的优质产品服务。",
          "经营范围": "服务:自动化设备、智能装备及AI系统、计算机软硬件、网络信息工程、云服务平台、机械产品、机器人及控制系统、通信设备的技术开发、技术服务、技术咨询、成果转让;批发、零售:自动化设备,智能装备及AI系统,机器人及控制系统,普通机械,仪器仪表,电子计算机及配件;货物进出口(法律、行政法规禁止经营的项目除外,法律、行政法规限制经营的项目取得许可证后方可经营);生产:切割机;其他无需报经审批的一切合法项目(依法须经批准的项目,经相关部门批准后方可开展经营活动)",
          "成立日期": "2005-03-11",
          "上市日期": "2021-03-19",
          "发行市盈率(倍)": 26.78,
          "网上发行日期": "2021-03-10",
          "发行方式": "战略配售,网上定价发行,网下询价配售,市值申购,高管员工参与配售,保荐机构参与配售",
          "每股面值(元)": 1,
          "发行量(股)": 14789598,
          "每股发行价(元)": 19.11,
          "发行费用(元)": 48007700,
          "发行总市值(元)": 282629217.78,
          "募集资金净额(元)": 234621500,
          "首日开盘价(元)": 44,
          "首日收盘价(元)": 43.61,
          "首日换手率": 85.3421,
          "首日最高价(元)": 48.2,
          "网下配售中签率": 0.02166877,
          "定价中签率": 0.02889497
        }


    """
    return company.get_company_info("SH{}".format(code))


if __name__ == '__main__':
    print(json_util.format_json(get_company_info('688092')))



# -*- coding: utf-8 -*-
"""
@File    : excel_util.py
@Date    : 2023-07-25
"""

from openpyxl.reader.excel import load_workbook



def read_excel(filename):
    book = load_workbook(filename)
    worksheet = book.worksheets[0]

    row_num = 0
    titles = []
    lst = []

    for row in worksheet.rows:
        row_num += 1

        if row_num == 1:
            # 表头
            for cell in row:
                # 移除空格
                value = cell.value.replace(' ', '')
                titles.append(value)
        else:
            # 内容
            item = {}
            for key, cell in zip(titles, row):
                item[key] = cell.value

            lst.append(item)

    return lst



# -*- coding: utf-8 -*-
"""
@File    : __init__.py.py
@Date    : 2023-07-17

上海证券交易所（上交所）

行情报表
http://www.sse.com.cn/market/price/report/

股票与存托凭证
http://www.sse.com.cn/assortment/stock/list/share/
"""